// $Id: CommandException.cc,v 1.3 2005/11/10 18:50:23 m9710797 Exp $

#include "CommandException.hh"


namespace openmsx {

CommandException::CommandException(const std::string& desc)
	: MSXException(desc)
{
}

SyntaxError::SyntaxError()
	: CommandException("Syntax error")
{
}

} // namespace openmsx

